nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Pint

Struct Pint 

pub struct Pint { /* private fields */ }
Pin interrupt and pattern match (PINT)

Implementations

Source

impl Pint

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn isel(self) -> Reg<Isel, RW>

Pin Interrupt Mode register

pub const fn ienr(self) -> Reg<Ienr, RW>

Pin interrupt level or rising edge interrupt enable register

pub const fn sienr(self) -> Reg<Sienr, W>

Pin interrupt level or rising edge interrupt set register

pub const fn cienr(self) -> Reg<Cienr, W>

Pin interrupt level (rising edge interrupt) clear register

pub const fn ienf(self) -> Reg<Ienf, RW>

Pin interrupt active level or falling edge interrupt enable register

pub const fn sienf(self) -> Reg<Sienf, W>

Pin interrupt active level or falling edge interrupt set register

pub const fn cienf(self) -> Reg<Cienf, W>

Pin interrupt active level or falling edge interrupt clear register

pub const fn rise(self) -> Reg<Rise, RW>

Pin interrupt rising edge register

pub const fn fall(self) -> Reg<Fall, RW>

Pin interrupt falling edge register

pub const fn ist(self) -> Reg<Ist, RW>

Pin interrupt status register

pub const fn pmctrl(self) -> Reg<Pmctrl, RW>

Pattern match interrupt control register

pub const fn pmsrc(self) -> Reg<Pmsrc, RW>

Pattern match interrupt bit-slice source register

pub const fn pmcfg(self) -> Reg<Pmcfg, RW>

Pattern match interrupt bit slice configuration register